// -----------------------------------------------------------------------------
// Copyright 2009-2012 Patrick Näf (herzbube@herzbube.ch)
//
// This file is part of the dgsmonX project.
//
// dgsmonX is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// dgsmonX is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with dgsmonX. If not, see <http://www.gnu.org/licenses/>.
// -----------------------------------------------------------------------------


#import <AppKit/AppKit.h>


// -----------------------------------------------------------------------------
/// @brief The DGSMonXApplication class is the principal class of the
/// application. Its purpose is to provide standard keyboard shortcuts for
/// Cut, Copy, Paste, Undo and Select All.
///
/// In normal applications, the standard keyboard shortcuts are provided by a
/// set of standard menu items in the application menubar. Because this is a
/// faceless application it can't have a menubar, hence the usual approach via
/// menu items is not possible.
///
/// The solution is to override sendEvent:() and to programmatically handle
/// keyboard shortcuts. The code in sendEvent:() was copy & pasted verbatim from
/// http://cocoa.flyingmac.com/2010/07/cut-copy-and-paste-in-lsuielement-applications/
///
/// @note An alternative to subclassing NSApplication might be to insert an
/// an event handler object into the first responder chain of the Preferences
/// window.
///
/// @note Info.plist refers to DGSMonXApplication in the key NSPrincipalClass.
/// This is how Mac OS X knows that it should instantiate DGSMonXApplication
/// instead of NSApplication.
// -----------------------------------------------------------------------------
@interface DGSMonXApplication : NSApplication

- (void) sendEvent:(NSEvent*)event;

@end
